summaryrefslogtreecommitdiff
path: root/makima/src/db
diff options
context:
space:
mode:
Diffstat (limited to 'makima/src/db')
-rw-r--r--makima/src/db/models.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/makima/src/db/models.rs b/makima/src/db/models.rs
index ec4ee15..bc90942 100644
--- a/makima/src/db/models.rs
+++ b/makima/src/db/models.rs
@@ -2849,13 +2849,13 @@ pub struct UpdateDirectiveRequest {
pub version: Option<i32>,
}
/// Directive with its chains for detail view.
#[derive(Debug, Serialize, ToSchema)]
#[serde(rename_all = "camelCase")]
pub struct DirectiveWithChains {
#[serde(flatten)]
pub directive: Directive,
- pub chains: Vec<DirectiveChain>,
+ pub chains: Vec<ChainWithSteps>,
}
/// Full row from directive_chains table.
@@ -2849,13 +2849,13 @@ pub struct UpdateDirectiveRequest {
pub version: Option<i32>,
}
-/// Directive with its chains for detail view.
+/// Directive with its chains and steps for detail view.
#[derive(Debug, Serialize, ToSchema)]
#[serde(rename_all = "camelCase")]